hasRightDistance function
Returns a RelativePositionAssert with the distance to the global right bound.
Implementation
RelativePositionAssert hasRightDistance(double right) =>
RelativePositionAssert.globalBounds(right: right);
Returns a RelativePositionAssert with the distance to the global right bound.
RelativePositionAssert hasRightDistance(double right) =>
RelativePositionAssert.globalBounds(right: right);